@@ -94,10 +94,11 @@ func RunOpenShiftControllerManager(config *openshiftcontrolplanev1.OpenShiftCont
 	}
 	go leaderelection.RunOrDie(context.Background(),
 		leaderelection.LeaderElectionConfig{
-			Lock:          rl,
-			LeaseDuration: config.LeaderElection.LeaseDuration.Duration,
-			RenewDeadline: config.LeaderElection.RenewDeadline.Duration,
-			RetryPeriod:   config.LeaderElection.RetryPeriod.Duration,
+			Lock:            rl,
+			ReleaseOnCancel: true,
+			LeaseDuration:   config.LeaderElection.LeaseDuration.Duration,
+			RenewDeadline:   config.LeaderElection.RenewDeadline.Duration,
+			RetryPeriod:     config.LeaderElection.RetryPeriod.Duration,
 			Callbacks: leaderelection.LeaderCallbacks{
 				OnStartedLeading: originControllerManager,
 				OnStoppedLeading: func() {
@@ -115,7 +116,7 @@ func WaitForHealthyAPIServer(client rest.Interface) error {
 	// important when we start apiserver and controller manager at the same time.
 	err := wait.PollImmediate(time.Second, 5*time.Minute, func() (bool, error) {
 		healthStatus := 0
-		resp := client.Get().AbsPath("/healthz").Do().StatusCode(&healthStatus)
+		resp := client.Get().AbsPath("/healthz").Do(context.TODO()).StatusCode(&healthStatus)
 		if healthStatus != http.StatusOK {
 			klog.Errorf("Server isn't healthy yet. Waiting a little while.")
 			return false, nil
